# Security Policy  
  
## Supported Versions  
  
| Version | Supported          |
| ------- | ------------------ |
| 1.0.0   | :white_check_mark: |
  
## Reporting a Vulnerability  
  
The easiest way to report is through GitHub's own system in the `Security` tab of this repo  
The alternate way is to report the vulnerability to [`willdev2025@outlook.com`](mailto:willdev2025@outlook.com) following the format below  
  
## Vulnerability Report Email Format  
  
Subject: 3-6 Word Description of Vulnerability  
From: youremail@example.com  
Content:  
  
Repository Name (Repository Link)  
DETAILED Description of Vulnerability  
